# redshells

[![Test](https://github.com/m3dev/redshells/actions/workflows/test.yml/badge.svg)](https://github.com/m3dev/redshells/actions/workflows/test.yml)
[![Python Versions](https://img.shields.io/pypi/pyversions/redshells.svg)](https://pypi.org/project/redshells/)
[![](https://img.shields.io/pypi/v/redshells)](https://pypi.org/project/redshells/)
![](https://img.shields.io/pypi/l/redshells)

Machine learning tasks which are used with data pipeline library "luigi" and its wrapper "gokart".
